.. role:: hidden
    :class: hidden-section

IO module
=========

.. automodule:: pyeeg.io
    :no-members:
    :no-inherited-members:

Classes
-------
.. currentmodule:: pyeeg.io

.. autosummary::
   :toctree: generated/
   :template: class.rst

   pyeeg.io.AlignedSpeech
   pyeeg.io.WordLevelFeatures

Functions
---------

.. autosummary:: 
    :toctree: generated/
    :template: function.rst

    pyeeg.io.eeglab2mne
    pyeeg.io.fieldtrip2mne
    pyeeg.io.load_mat
    pyeeg.io.load_ica_matrices
    pyeeg.io.extract_duration_audio
    pyeeg.io.extract_duration_praat
    pyeeg.io.get_sentence_position
    pyeeg.io.load_surprisal_values
    pyeeg.io.load_wordfreq_values
    pyeeg.io.load_depth_values
    pyeeg.io.load_open_values
    pyeeg.io.load_close_values
    pyeeg.io.get_word_onsets
    pyeeg.io.get_word_vectors
